@@ -5,26 +5,17 @@
 class PCATTYPE:
     """
     A class representing Project Code Types
-
-    ...
-
-    Attributes
-    ----------
-    uid: str
-        Unique ID [proj_catg_type_id]
-    max_length: int
-        Max Code Length [proj_catg_short_len]
-    name: str
-        Activity Code [proj_catg_type]
-    seq_num: int | None
-        Sort Order
     """
 
-    def __init__(self, **data) -> None:
+    def __init__(self, **data: str) -> None:
         self.uid: str = data["proj_catg_type_id"]
+        """Unique Table ID"""
         self.max_length: int = int(data["proj_catg_short_len"])
+        """Max Character Length"""
         self.name: str = data["proj_catg_type"]
+        """Project Code Name"""
         self.seq_num: int | None = None if (seq := data["seq_num"]) == "" else int(seq)
+        """Sort Order"""
 
     def __eq__(self, __o: "PCATTYPE") -> bool:
         return all(
